==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/MicroTimeBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MicroTimeBuilder extends io.fabric8.kubernetes.api.model.MicroTimeFluentImpl<io.fabric8.kubernetes.api.model.MicroTimeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.MicroTime,io.fabric8.kubernetes.api.model.MicroTimeBuilder>{
  public MicroTimeBuilder() {
    this(false);
  }
  public MicroTimeBuilder(java.lang.Boolean validationEnabled) {
    this(new MicroTime(), validationEnabled);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent) {
    this(fluent, false);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MicroTime(), validationEnabled);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent,io.fabric8.kubernetes.api.model.MicroTime instance) {
    this(fluent, instance, false);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent,io.fabric8.kubernetes.api.model.MicroTime instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withTime(instance.getTime()); 
    this.validationEnabled = validationEnabled; 
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTime instance) {
    this(instance,false);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTime instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withTime(instance.getTime()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.MicroTime build() {
    MicroTime buildable = new MicroTime(fluent.getTime());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MicroTimeBuilder that = (MicroTimeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/MicroTimeBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MicroTimeBuilder extends io.fabric8.kubernetes.api.model.MicroTimeFluentImpl<io.fabric8.kubernetes.api.model.MicroTimeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.MicroTime,io.fabric8.kubernetes.api.model.MicroTimeBuilder>{
  public MicroTimeBuilder() {
    this(false);
  }
  public MicroTimeBuilder(java.lang.Boolean validationEnabled) {
    this(new MicroTime(), validationEnabled);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent) {
    this(fluent, false);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MicroTime(), validationEnabled);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent,io.fabric8.kubernetes.api.model.MicroTime instance) {
    this(fluent, instance, false);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent,io.fabric8.kubernetes.api.model.MicroTime instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withTime(instance.getTime()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTime instance) {
    this(instance,false);
  }
  public MicroTimeBuilder(io.fabric8.kubernetes.api.model.MicroTime instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withTime(instance.getTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.MicroTimeFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.MicroTime build() {
    MicroTime buildable = new MicroTime(fluent.getTime());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MicroTimeBuilder that = (MicroTimeBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
